Module update

Module update 

An experimental module providing a way to update method parameters in aspects.

Traits

Update
The trait Update allows a value to be updated while guaranteeing the return type is the same.
UpdateRef
The trait UpdateRef allows a value to be updated by using its reference.